@@ -206,7 +206,7 @@ class Network(NodeConfigFileSection):
 
     >>> from ovirt.node.utils import fs
     >>> n = Network(fs.FakeFs.File("dst"))
-    >>> n.update("eth0", None, "10.0.0.1", "255.0.0.0", "10.0.0.255",
+    >>> _ = n.update("eth0", None, "10.0.0.1", "255.0.0.0", "10.0.0.255",
     ...          "20")
     >>> data = sorted(n.retrieve().items())
     >>> data[:3]
@@ -457,7 +457,7 @@ class NicBonding(NodeConfigFileSection):
 
     >>> from ovirt.node.utils import fs
     >>> n = NicBonding(fs.FakeFs.File("dst"))
-    >>> n.update("bond0", ["ens1", "ens2", "ens3"], "mode=4")
+    >>> _ = n.update("bond0", ["ens1", "ens2", "ens3"], "mode=4")
     >>> data = sorted(n.retrieve().items())
     >>> data[:2]
     [('name', 'bond0'), ('options', 'mode=4')]
@@ -571,7 +571,7 @@ class NetworkLayout(NodeConfigFileSection):
 
     >>> from ovirt.node.utils import fs
     >>> n = NetworkLayout(fs.FakeFs.File("dst"))
-    >>> n.update("bridged")
+    >>> _ = n.update("bridged")
     >>> sorted(n.retrieve().items())
     [('layout', 'bridged')]
     """
@@ -611,7 +611,7 @@ class IPv6(NodeConfigFileSection):
 
     >>> from ovirt.node.utils import fs
     >>> n = IPv6(fs.FakeFs.File("dst"))
-    >>> n.update("auto", "11::22", "42", "11::44")
+    >>> _ = n.update("auto", "11::22", "42", "11::44")
     >>> data = sorted(n.retrieve().items())
     >>> data[0:3]
     [('bootproto', 'auto'), ('gateway', '11::44'), ('ipaddr', '11::22')]
@@ -672,7 +672,7 @@ class Hostname(NodeConfigFileSection):
     >>> from ovirt.node.utils import fs
     >>> n = Hostname(fs.FakeFs.File("dst"))
     >>> hostname = "host.example.com"
-    >>> n.update(hostname)
+    >>> _ = n.update(hostname)
     >>> n.retrieve()
     {'hostname': 'host.example.com'}
     """
@@ -737,11 +737,11 @@ class Nameservers(NodeConfigFileSection):
     >>> from ovirt.node.utils import fs
     >>> n = Nameservers(fs.FakeFs.File("dst"))
     >>> servers = ["10.0.0.2", "10.0.0.3"]
-    >>> n.update(servers)
+    >>> _ = n.update(servers)
     >>> data = n.retrieve()
     >>> all([servers[idx] == s for idx, s in enumerate(data["servers"])])
     True
-    >>> n.update([])
+    >>> _ = n.update([])
     >>> n.retrieve()
     {'servers': None}
     """
@@ -836,11 +836,11 @@ class Timeservers(NodeConfigFileSection):
     >>> from ovirt.node.utils import fs
     >>> n = Timeservers(fs.FakeFs.File("dst"))
     >>> servers = ["10.0.0.4", "10.0.0.5", "0.example.com"]
-    >>> n.update(servers)
+    >>> _ = n.update(servers)
     >>> data = n.retrieve()
     >>> all([servers[idx] == s for idx, s in enumerate(data["servers"])])
     True
-    >>> n.update([])
+    >>> _ = n.update([])
     >>> n.retrieve()
     {'servers': None}
     """
@@ -912,7 +912,7 @@ class Syslog(NodeConfigFileSection):
     >>> n = Syslog(fs.FakeFs.File("dst"))
     >>> server = "10.0.0.6"
     >>> port = "514"
-    >>> n.update(server, port)
+    >>> _ = n.update(server, port)
     >>> sorted(n.retrieve().items())
     [('port', '514'), ('server', '10.0.0.6')]
     """
@@ -950,7 +950,7 @@ class Collectd(NodeConfigFileSection):
     >>> n = Collectd(fs.FakeFs.File("dst"))
     >>> server = "10.0.0.7"
     >>> port = "42"
-    >>> n.update(server, port)
+    >>> _ = n.update(server, port)
     >>> sorted(n.retrieve().items())
     [('port', '42'), ('server', '10.0.0.7')]
     """
@@ -994,7 +994,7 @@ class KDump(NodeConfigFileSection):
     >>> n = KDump(fs.FakeFs.File("dst"))
     >>> nfs_url = "host.example.com:/dst/path"
     >>> ssh_url = "root@host.example.com"
-    >>> n.update(nfs_url, ssh_url, True)
+    >>> _ = n.update(nfs_url, ssh_url, True)
     >>> d = sorted(n.retrieve().items())
     >>> d[:2]
     [('local', True), ('nfs', 'host.example.com:/dst/path')]
@@ -1152,7 +1152,7 @@ class iSCSI(NodeConfigFileSection):
 
     >>> from ovirt.node.utils import fs
     >>> n = iSCSI(fs.FakeFs.File("dst"))
-    >>> n.update("iqn.1992-01.com.example:node",
+    >>> _ = n.update("iqn.1992-01.com.example:node",
     ...          "iqn.1992-01.com.example:target", "10.0.0.8", "42")
     >>> data = sorted(n.retrieve().items())
     >>> data[:2]
@@ -1196,7 +1196,7 @@ class Netconsole(NodeConfigFileSection):
     >>> n = Netconsole(fs.FakeFs.File("dst"))
     >>> server = "10.0.0.9"
     >>> port = "666"
-    >>> n.update(server, port)
+    >>> _ = n.update(server, port)
     >>> sorted(n.retrieve().items())
     [('port', '666'), ('server', '10.0.0.9')]
     """
@@ -1230,7 +1230,7 @@ class Logrotate(NodeConfigFileSection):
     >>> from ovirt.node.utils import fs
     >>> n = Logrotate(fs.FakeFs.File("dst"))
     >>> max_size = "42"
-    >>> n.update(max_size)
+    >>> _ = n.update(max_size)
     >>> n.retrieve().items()
     [('max_size', '42')]
     """
@@ -1266,7 +1266,7 @@ class Keyboard(NodeConfigFileSection):
     >>> from ovirt.node.utils import fs
     >>> n = Keyboard(fs.FakeFs.File("dst"))
     >>> layout = "de_DE.UTF-8"
-    >>> n.update(layout)
+    >>> _ = n.update(layout)
     >>> n.retrieve()
     {'layout': 'de_DE.UTF-8'}
     """
@@ -1303,7 +1303,7 @@ class NFSv4(NodeConfigFileSection):
     >>> from ovirt.node.utils import fs
     >>> n = NFSv4(fs.FakeFs.File("dst"))
     >>> domain = "foo.example"
-    >>> n.update(domain)
+    >>> _ = n.update(domain)
     >>> n.retrieve().items()
     [('domain', 'foo.example')]
     """
@@ -1325,7 +1325,9 @@ class NFSv4(NodeConfigFileSection):
 
             def commit(self):
                 nfsv4 = storage.NFSv4()
-                nfsv4.domain(domain)
+
+                # Need to pass "" to disable Domain line
+                nfsv4.domain(domain or "")
 
                 fs.Config().persist(nfsv4.configfilename)
                 system.service("rpcidmapd", "restart")
@@ -1344,7 +1346,7 @@ class SSH(NodeConfigFileSection):
     >>> pwauth = True
     >>> num_bytes = "24"
     >>> disable_aesni = True
-    >>> n.update(pwauth, num_bytes, disable_aesni)
+    >>> _ = n.update(pwauth, num_bytes, disable_aesni)
     >>> sorted(n.retrieve().items())
     [('disable_aesni', True), ('num_bytes', '24'), ('pwauth', True)]
     """
@@ -1408,7 +1410,7 @@ class Installation(NodeConfigFileSection):
     >>> from ovirt.node.utils import fs
     >>> n = Installation(fs.FakeFs.File("dst"))
     >>> kwargs = {"init": ["/dev/sda"], "root_install": "1"}
-    >>> n.update(**kwargs)
+    >>> _ = n.update(**kwargs)
     >>> data = n.retrieve().items()
     """
     keys = ("OVIRT_INIT",
@@ -1528,3 +1530,9 @@ class Management(NodeConfigFileSection):
 
     def transaction(self):
         return None
+
+    def is_managed(self):
+        return True if self.retrieve()["managed_by"] else False
+
+    def has_managed_ifnames(self):
+        return True if self.retrieve()["managed_ifnames"] else False
